/*******************************************************************************
 * Copyright 2017 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.finanzen;

import java.util.List;

/**
 * Interface für eine Datenquelle
 *
 * @author Frank Münster
 * @param <I>
 *            der StockInfoBean der Datenquelle
 */
public interface DatenQuelleApi<I extends StockInfoBean> {

    /**
     * Sucht nach Wertpapieren und liefert eine entsprechende Liste zurück
     *
     * @param searchText
     * @return Liste mit gefundenen Wertpapieren
     * @throws FinanceException
     */
    List<I> getSearchResults(String searchText) throws FinanceException;

    /**
     * Aktualisiert ein Wertpapier
     *
     * @param stock
     * @return das aktualisierte StockInfoBean
     * @throws FinanceException
     */
    I getActualValue(I stock) throws FinanceException;

    /**
     * Liest die historischen Daten, falls verfügbar
     *
     * @param stock
     * @return das aktualisierte StockInfoBean
     * @throws FinanceException
     */
    I loadHistoryValues(I stock) throws FinanceException;
}
