/*******************************************************************************
 * Copyright 2017 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.finanzen;

import java.time.LocalDate;
import java.util.Arrays;

/**
 * Ein Wertpapier-Wert Bean
 *
 * @author Frank Münster
 */
public class HistoryValueBean implements Comparable<HistoryValueBean> {

    /**
     * Ein eindeutiger Identifikations String. Zum Beispiel das Yahoo-Symbol
     * oder der Wertpapier Name
     */
    private String idString;

    /**
     * Das Datum
     */
    private LocalDate localDate;

    /**
     * Der Er&ouml;ffnugskurs
     */
    private double open = Double.NaN;

    /**
     * Der Tagesh&ouml;chststand
     */
    private double high = Double.NaN;

    /**
     * Der Tagesniedrigsstand
     */
    private double low = Double.NaN;

    /**
     * Der Schlusskurs
     */
    private double close = Double.NaN;

    /**
     * Das Umsatzvolumen
     */
    private double volume;

    /**
     * der angepasste Schusskurs
     */
    private double adjClose = Double.NaN;

    /**
     * Standartkonstruktor
     *
     * @param idString
     *            ID des Wertpapiers
     */
    public HistoryValueBean(final String idString) {
        this.idString = idString;
    }

    /**
     * Liefert den eindeutigen Namen
     *
     * @return symbol der eindeutigen Namen
     */
    public String getIdString() {

        return this.idString;
    }

    /**
     * Setzt den eindeutigen Namen
     *
     * @param idString
     *            der eindeutigen Namen
     */
    public void setIdString(final String idString) {

        this.idString = idString;
    }

    /**
     * Liefert das Datum
     *
     * @return localDate das datum
     */
    public LocalDate getLocalDate() {

        return this.localDate;
    }

    /**
     * Setzt das Datum
     *
     * @param localDate
     *            das Datum
     */
    public void setLocalDate(final LocalDate localDate) {

        this.localDate = localDate;
    }

    /**
     * Liefert den Er&ouml;ffnugskurs
     *
     * @return open Der Er&ouml;ffnugskurs
     */
    public double getOpen() {

        return this.open;
    }

    /**
     * Setzt den Er&ouml;ffnugskurs
     *
     * @param open
     *            Der Er&ouml;ffnugskurs
     */
    public void setOpen(final double open) {

        this.open = open;
    }

    /**
     * Liefert den Tagesh&ouml;chststand
     *
     * @return high der Tagesh&ouml;chststand
     */
    public double getHigh() {

        return this.high;
    }

    /**
     * Setzt den Tagesh&ouml;chststand
     *
     * @param high
     *            der Tagesh&ouml;chststand
     */
    public void setHigh(final double high) {

        this.high = high;
    }

    /**
     * Liefert den Tagesniedrigsstand
     *
     * @return low der Tagesniedrigsstand
     */
    public double getLow() {

        return this.low;
    }

    /**
     * Setzte den Tagesniedrigsstand
     *
     * @param low
     *            der Tagesniedrigsstand
     */
    public void setLow(final double low) {

        this.low = low;
    }

    /**
     * Liefert den Schlusskurs
     *
     * @return close der Schlusskurs
     */
    public double getClose() {

        return this.close;
    }

    /**
     * Setzt den Schlusskurs
     *
     * @param close
     *            der Schlusskurs
     */
    public void setClose(final double close) {

        this.close = close;
    }

    /**
     * Liefert das Umsatzvolumen
     *
     * @return volume das Umsatzvolumen
     */
    public double getVolume() {

        return this.volume;
    }

    /**
     * Setzt das Umsatzvolumen
     *
     * @param volume
     *            das Umsatzvolumen
     */
    public void setVolume(final double volume) {

        this.volume = volume;
    }

    /**
     * Liefert den angepasste Schlusskurs
     *
     * @return adjClose der angepasste Schlusskurs
     */
    public double getAdjClose() {

        return this.adjClose;
    }

    /**
     * Setzt den angepasste Schlusskurs
     *
     * @param adjClose
     *            der angepasste Schlusskurs
     */
    public void setAdjClose(final double adjClose) {

        this.adjClose = adjClose;
    }

    /**
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    @SuppressWarnings("PMD.OnlyOneReturn")
    public boolean equals(final Object obj) {

        if (obj == null) {
            return false;
        }
        if (!(obj instanceof HistoryValueBean)) {
            return false;
        }

        // Cats to HistoryValueBean
        final HistoryValueBean histObj = (HistoryValueBean) obj;

        if (this.adjClose != histObj.adjClose) {
            return false;
        }

        if (this.close != histObj.close) {
            return false;
        }

        if (this.high != histObj.high) {
            return false;
        }

        if (!this.idString.equals(histObj.idString)) {
            return false;
        }

        if (!this.localDate.equals(histObj.localDate)) {
            return false;
        }

        if (this.low != histObj.low) {
            return false;
        }

        if (this.open != histObj.open) {
            return false;
        }

        // Finally compare volume and return
        return this.volume == histObj.volume;
    }

    /**
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    @Override
    public int compareTo(final HistoryValueBean historyValueBean) {

        int compareTo;
        if (historyValueBean.localDate == null && this.localDate == null) {
            compareTo = 0;
        } else if (this.localDate == null) {
            compareTo = 1;
        } else if (historyValueBean.localDate == null) {
            compareTo = -1;
        } else {
            compareTo = this.localDate.compareTo(historyValueBean.localDate);
        }
        return compareTo;
    }

    /**
     * Nice String for printout
     */
    @Override
    public String toString() {

        final StringBuilder result = new StringBuilder(this.idString).append(", "); //$NON-NLS-1$
        result.append(this.getLocalDate().toString()).append(", ") //$NON-NLS-1$
                .append(this.getClose()).append(", ") //$NON-NLS-1$
                .append(this.getVolume());
        return result.toString();
    }

    /**
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {

        return Arrays.hashCode(new Object[] { this.adjClose, this.close, this.idString, this.localDate, this.low,
                this.open, this.volume });
    }
}
