/*******************************************************************************
 * Copyright 2017 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.finanzen;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author Frank Münster
 */
public class StockInfoBean {

    /**
     * Aktueller Kurs
     */
    protected BigDecimal actValue;

    /**
     * Die prozentuale Änderung zum Vortag
     */
    protected BigDecimal changeRate;

    /**
     * Die Währung
     */
    protected String currency;

    /**
     * Datum und Zeit
     */
    protected Date date;

    /**
     * Ein Beschreibung
     */
    protected String description;

    /**
     * B&ouml;senplatz
     */
    protected String exchange;

    /**
     * Die historischen Wertpapierdaten
     */
    protected WertpapierHistory historyValues;

    /**
     * Wertpapiername
     */
    protected String name;

    /**
     * Wertpapiertyp
     */
    protected String type;

    /**
     * Standardkonstruktor
     */
    public StockInfoBean() {
        super();
    }

    /**
     * Konstruktor mit Angabe den wichtigsten Feldern.
     *
     * @param name
     *            der Wertpapiername
     * @param exchange
     *            Der B&ouml;rsenplatz
     * @param type
     *            Der Wertpapiertyp
     * @param description
     *            Die Beschreibung
     */
    public StockInfoBean(final String name, final String exchange, final String type, final String description) {
        this.name = name;
        this.exchange = exchange;
        this.type = type;
        this.description = description;
    }

    /**
     * Liefert den aktuellen Wert
     *
     * @return the actValue
     */
    public BigDecimal getActValue() {

        return this.actValue;
    }

    /**
     * Liefert die prozentuale Änderung zum Vortag
     *
     * @return die prozentuale Änderung zum Vortag
     */
    public BigDecimal getChangeRate() {

        return this.changeRate;
    }

    /**
     * @return the currency
     */
    public String getCurrency() {

        return this.currency;
    }

    /**
     * Liefert das Datum und die Uhrzeit
     *
     * @return the date
     */
    public Date getDate() {

        return this.date;
    }

    /**
     * @return the description
     */
    public String getDescription() {

        return this.description;
    }

    /**
     * Liefert den b&ouml;rsenplatz
     *
     * @return der b&ouml;rsenplatz
     */
    public String getExchange() {

        return this.exchange;
    }

    /**
     * @return the historyValues
     */
    public WertpapierHistory getHistoryValues() {

        return this.historyValues;
    }

    /**
     * Liefert den Wertpapiernamen
     *
     * @return der Wertpapiernamen
     */
    public String getName() {

        return this.name;
    }

    /**
     * Liefert den Wertpapiertyp
     *
     * @return der Wertpapiertyp
     */
    public String getType() {

        return this.type;
    }

    /**
     * Setzt den aktuellen Wert
     *
     * @param actValue
     *            the actValue to set
     */
    public void setActValue(final BigDecimal actValue) {

        this.actValue = actValue;
    }

    /**
     * Setzt die prozentuale Änderung zum Vortag
     *
     * @param changeRate
     *            die prozentuale Änderung zum Vortag
     */
    public void setChangeRate(final BigDecimal changeRate) {

        this.changeRate = changeRate;
    }

    /**
     * Setzt die Währung
     *
     * @param currency
     *            the currency to set
     */
    public void setCurrency(final String currency) {

        this.currency = currency;
    }

    /**
     * Setzt das Datum und die Uhrzeit
     *
     * @param date
     *            the date to set
     */
    public void setDate(final Date date) {

        this.date = date;
    }

    /**
     * Setzt die Beschreibung
     *
     * @param description
     */
    public void setDescription(final String description) {

        this.description = description;
    }

    /**
     * Setzt den Börsenplatz
     *
     * @param exchange
     *            der Börsenplatz
     */
    public void setExchange(final String exchange) {

        this.exchange = exchange;
    }

    /**
     * @param historyValues
     *            the historyValues to set
     */
    public void setHistoryValues(final WertpapierHistory historyValues) {

        this.historyValues = historyValues;
    }

    /**
     * Setzt den Wertpapiernamen
     *
     * @param name
     *            der Wertpapiernamen
     */
    public void setName(final String name) {

        this.name = name;
    }

    /**
     * Setzt den Wertpapiertyp
     *
     * @param type
     *            der Wertpapiertyp
     */
    public void setType(final String type) {

        this.type = type;
    }

    /**
     * @see Object#toString()
     */
    @Override
    public String toString() {

        final StringBuilder stringBuffer = new StringBuilder();
        if (this.name != null) {
            stringBuffer.append('\t');
            stringBuffer.append(this.name);
        }
        if (this.exchange != null) {
            stringBuffer.append('\t');
            stringBuffer.append(this.exchange);
        }
        if (this.type != null) {
            stringBuffer.append('\t');
            stringBuffer.append(this.type);
        }
        return stringBuffer.toString();
    }
}
