/*******************************************************************************
 * Copyright 2017 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.finanzen.boerseard;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

import de.frankmuenster.jameica.finanzen.FinanceException;
import de.frankmuenster.jameica.finanzen.HistoryValueBean;
import de.frankmuenster.jameica.finanzen.WertpapierHistory;
import de.frankmuenster.jameica.finanzen.boerseard.json.DateValue;
import de.frankmuenster.jameica.finanzen.boerseard.json.JsonArdBoerseHistory;

/**
 * @author Frank Münster
 */
public class ArdBoerseWertpapierHistory implements WertpapierHistory {

    /**
     * Die Liste mit dem historischen Werten
     */
    private List<HistoryValueBean> values;

    /**
     * Liefert eine Instanz der ArdBoerseWertpapierHistory
     *
     * @param stockID
     * @param histValues
     * @param histVolumne
     */
    public ArdBoerseWertpapierHistory(final String stockID, final JsonArdBoerseHistory histValues,
            final JsonArdBoerseHistory histVolumne) {
        this.readHistory(stockID, histValues, histVolumne);
    }

    /**
     * @see WertpapierHistory#getValues()
     */
    @Override
    public List<HistoryValueBean> getValues() throws FinanceException {

        return this.values;
    }

    /**
     * @see WertpapierHistory#getSourceName()
     */
    @Override
    public String getSourceName() {

        return "Börese ARD"; //$NON-NLS-1$
    }

    /**
     * @param stockID
     * @param histVolumne
     * @param histValues
     */
    private void readHistory(final String stockID, final JsonArdBoerseHistory histValues,
            final JsonArdBoerseHistory histVolumne) {

        // Werte in HistoryValueBean laden
        this.values = new ArrayList<>();
        for (final DateValue dateValue : histValues.getData()) {
            final HistoryValueBean bean = new HistoryValueBean(stockID); // NOPMD
            bean.setIdString(stockID);
            bean.setLocalDate(dateValue.getDate());
            bean.setClose(dateValue.getValue().doubleValue());
            final double vol = this.getVolume(histVolumne, bean.getLocalDate());
            bean.setVolume(vol);
            this.values.add(bean);
        }
    }

    /**
     * Liefert das Volumen an den angegeben Tag.
     *
     * @param histVolumne
     * @param date
     * @return das Volumen an den angegeben Tag.
     */
    private double getVolume(final JsonArdBoerseHistory histVolumne, final LocalDate date) {

        double vol = 0;
        if (histVolumne != null) {
            for (final DateValue historyValueBean : histVolumne.getData()) {
                if (historyValueBean.getDate().equals(date)) {
                    vol = historyValueBean.getValue().doubleValue();
                    break;
                }
            }
        }
        return vol;
    }
}
