/*******************************************************************************
 * Copyright 2017 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.jameica.finanzen.boerseard.json;

import java.math.BigDecimal;
import java.time.Instant;
import java.time.LocalDate;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.List;

import de.frankmuenster.jameica.json.Deserialiser;

/**
 * @author Frank Münster
 */
public class DateValueDeserialiser implements Deserialiser<List<DateValue>> {

    /**
     * Standard Konstruktor
     */
    public DateValueDeserialiser() {
        // Absichtlich leer
    }

    /**
     * @see de.frankmuenster.jameica.json.Deserialiser#deserialize(java.lang.Object)
     */
    @Override
    public List<DateValue> deserialize(final Object jsonPart) {

        final List<DateValue> values = new ArrayList<>();
        @SuppressWarnings("unchecked")
        final List<Object> dataList = (List<Object>) jsonPart;
        dataList.forEach(data -> {
            final Double dateDbl = (Double) ((List<?>) data).get(0);
            final LocalDate date = this.doubleToLocalDate(dateDbl);
            final Double valueDbl = (Double) ((List<?>) data).get(1);
            final BigDecimal value = BigDecimal.valueOf(valueDbl);
            values.add(new DateValue(date, value));
        });
        return values;
    }

    private LocalDate doubleToLocalDate(final Double date) {

        final Long dateLong = date.longValue();
        return Instant.ofEpochMilli(dateLong).atZone(ZoneId.systemDefault()).toLocalDate();
    }
}
