/*******************************************************************************
 * Copyright 2017 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.finanzen.currency;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;

/**
 * Enumeration for currencies supported by the ECB including a dummy currency
 * for indexes
 */
public enum Currency {
    /**
     * Australischer Dollar
     */
    AUD("AUD", CurrencyName.getString("Currency.aud"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Lew (Bulgarien)
     */
    BGN("BGN", CurrencyName.getString("Currency.bgn"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Brasilianischer Real
     */
    BRL("BRL", CurrencyName.getString("Currency.brl"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Kanadischer Dollar
     */
    CAD("CAD", CurrencyName.getString("Currency.cad"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Schweizer Franken
     */
    CHF("CHF", CurrencyName.getString("Currency.chf"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Chinesischer Yuan
     */
    CNY("CNY", CurrencyName.getString("Currency.cny"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Tschechische Krone
     */
    CZK("CZK", CurrencyName.getString("Currency.czk"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Dänische Krone
     */
    DKK("DKK", CurrencyName.getString("Currency.dkk"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Euro
     */
    EUR("EUR", CurrencyName.getString("Currency.eur"), "€"), //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
    /**
     * Pfund Sterling
     */
    GBP("GBP", CurrencyName.getString("Currency.gbp"), "£"), //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
    /**
     * Hongkong-Dollar
     */
    HKD("HKD", CurrencyName.getString("Currency.hkd"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Kuna (Kroatien)
     */
    HRK("HRK", CurrencyName.getString("Currency.hrk"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Forint (Ungarn)
     */
    HUF("HUF", CurrencyName.getString("Currency.huf"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Indonesische Rupiah
     */
    IDR("IDR", CurrencyName.getString("Currency.idr"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Dummy currency for indexes
     */
    IDX("IDX", CurrencyName.getString("Currency.idx"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Neuer Israel Scheke
     */
    ILS("ILS", CurrencyName.getString("Currency.ils"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Indische Rupie
     */
    INR("INR", CurrencyName.getString("Currency.inr"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Japanischer Yen
     */
    JPY("JPY", CurrencyName.getString("Currency.jpy"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Südkoreanischer Won
     */
    KRW("KRW", CurrencyName.getString("Currency.krw"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Mexikanischer Peso
     */
    MXN("MXN", CurrencyName.getString("Currency.mxn"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Malaysische Ringgit
     */
    MYR("MYR", CurrencyName.getString("Currency.myr"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Norwegische Krone
     */
    NOK("NOK", CurrencyName.getString("Currency.nok"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Neuseeland-Dollar
     */
    NZD("NZD", CurrencyName.getString("Currency.nzd"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Philippinischer Peso
     */
    PHP("PHP", CurrencyName.getString("Currency.php"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Zloty (Polen
     */
    PLN("PLN", CurrencyName.getString("Currency.pln"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Rumänischer Leu
     */
    RON("RON", CurrencyName.getString("Currency.ron"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Russischer Rubel
     */
    RUB("RUB", CurrencyName.getString("Currency.rub"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Schwedische Krone
     */
    SEK("SEK", CurrencyName.getString("Currency.sek"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Singapur-Dollar
     */
    SGD("SGD", CurrencyName.getString("Currency.sgd"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Thailändische Baht
     */
    THB("THB", CurrencyName.getString("Currency.thb"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * Neue Türkische Lira
     */
    TRY("TRY", CurrencyName.getString("Currency.rty"), StringUtils.EMPTY), //$NON-NLS-1$ //$NON-NLS-2$
    /**
     * US Dolloar
     */
    USD("USD", CurrencyName.getString("Currency.usd"), "$"), //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
    /**
     * Südafrikanischer RAND
     */
    ZAR("ZAR", CurrencyName.getString("Currency.zar"), StringUtils.EMPTY); //$NON-NLS-1$ //$NON-NLS-2$

    /**
     * Der W&auml;hrungscode nach ISO-4217
     */
    private String cur;

    /**
     * Der Name der W&auml;hrung (freie Nameswahl)
     */
    private String name;

    /**
     * Das Symbol der W&auml;hrung (freie Nameswahl)
     */
    private String symbol;

    /**
     * Liefert die Liste der bekannten Codes.
     *
     * @return die Liste der bekannten Codes.
     */
    public static List<String> codes() {

        final List<String> result = new ArrayList<>();
        for (final Currency c : Currency.values()) {
            result.add(c.getCode());
        }
        return result;
    }

    /**
     * Ermittelt den W&auml;hrungs-Code.
     *
     * @param currencyName
     *            der W&auml;hrung. Kann NULL sein.
     * @return der W&auml;hrungs-Code oder NULL, wenn der Code nicht bekannt
     *         ist.
     */
    public static Currency find(final String currencyName) {

        Currency currency = null;
        if (StringUtils.trimToNull(currencyName) != null) {
            for (final Currency pc : Currency.values()) {
                if (pc.getCode().equals(currencyName)) {
                    currency = pc;
                    break;
                }
            }
        }
        return currency;
    }

    /**
     * Ermittelt den W&auml;hrungs-Code.
     *
     * @param symbol
     * @return der W&auml;hrungs-Code oder NULL, wenn der Code nicht bekannt
     *         ist.
     */
    public static Currency findSymbol(final String symbol) {

        Currency currency = null;
        if (StringUtils.trimToNull(symbol) != null) {
            for (final Currency pc : Currency.values()) {
                if (pc.getSymbol().equals(symbol)) {
                    currency = pc;
                    break;
                }
            }
        }
        return currency;
    }

    /**
     * ct.
     *
     * @param cur
     *            die W&auml;hrung.
     * @param name
     *            die sprechende Bezeichnung.
     * @param symbol
     */
    private Currency(final String cur, final String name, final String symbol) {
        this.cur = cur;
        this.name = name;
        this.symbol = symbol;
    }

    /**
     * Liefert die W&auml;hrung.
     *
     * @return cur ddie W&auml;hrung.
     */
    public String getCode() {

        return this.cur;
    }

    /**
     * Liefert einen sprechenden Namen f&uuml;r die W&auml;hrung.
     *
     * @return sprechender Name f&uuml;r die W&auml;hrung.
     */
    public String getName() {

        return this.name;
    }

    /**
     * @see java.lang.Enum#toString()
     */
    @Override
    public String toString() {

        return this.getName();
    }

    /**
     * Liefert das Symbol oder einen leeren String, falls es keines gibt.
     *
     * @return das Symbol oder einen leeren String
     */
    public Object getSymbol() {

        return this.symbol;
    }
}
