/*******************************************************************************
 * Copyright 2017 fmCreation
 *  
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europäischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie dürfen dieses Werk ausschließlich gemäß dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 * 
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 * 
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschränkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/
package de.frankmuenster.jameica.finanzen.currency;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * &Uuml;bersetzer Klasse zum Ermitteln der W&auml;hrungen in der jeweiligen Localen.
 *
 * @author Frank Münster
 */
public final class CurrencyName {

    /**
     * Resource Pfad zu den W&auml;hrungsnamen
     */
    private static final String RESOURCE_PATH = "lang.currency"; //$NON-NLS-1$

    /**
     * Das Resource Bundle mit der Sprachdatei
     */
    private static ResourceBundle bundle;
    static {
        try {
            CurrencyName.bundle = ResourceBundle.getBundle(CurrencyName.RESOURCE_PATH, Locale.getDefault());
        } catch (final MissingResourceException e) {
            // Wir laden die deutsche Sprachdatei
            final Locale locale = new Locale("de", "DE"); //$NON-NLS-1$ //$NON-NLS-2$
            CurrencyName.bundle = ResourceBundle.getBundle(CurrencyName.RESOURCE_PATH, locale);
        }
    }

    private CurrencyName() {
        // Absichlich leer
    }

    /**
     * Liefert den W&auml;hrungsnamen in der aktuellen Local
     *
     * @param key
     *            das W&aumlhrungsk&uuml;tzel
     * @return den W&auml;hrungsnamen in der aktuellen Local
     */
    public static String getString(final String key) {
        String result;
        try {
            result = CurrencyName.bundle.getString(key);
        } catch (final MissingResourceException e) {
            result = '!' + key + '!';
        }
        return result;
    }
}
